# Multiply EGO
EGO and multiply EGO method.


[![Python Versions](https://img.shields.io/pypi/pyversions/multiego.svg)](https://pypi.org/project/multiego/)
[![Version](https://img.shields.io/github/tag/MGEdata/multiego.svg)](https://github.com/MGEdata/multiego/releases/latest)
![pypi Versions](https://badge.fury.io/py/multiego.svg)

# Install
```bash
pip install multiego
```

link
-----------
More powerful can be found  [mipego](https://github.com/wangronin/MIP-EGO)